==> rho-common-facade-1.0.0-sources.jar: cn/smarthse/rho/modules/sys/entity/s/SupervisionExeLawInfo.java <==
package cn.smarthse.rho.modules.sys.entity.s;

import java.io.Serializable;
import java.util.Date;
import javax.persistence.*;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;


@ApiModel(value = "放射卫生执法处罚 对象", description = "医院：放射卫生执法处罚")
@TableName("supervision_exe_law_info")
@Data
public class SupervisionExeLawInfo implements Serializable{
	private static final long serialVersionUID = 1L;
	/**
	 * ID
	 */
	@TableId(value = "id", type = IdType.ASSIGN_ID)
	private Long id;
	/**
	 * 医院分院id
	 */
	private Long cid;
	/**
	 * 医院分院名称
	 */
	private String compName;
	/**
	 * 医院主院id
	 */
	private Long mainCid;
	/**
	 * 对应主院医院名称
	 */
	private String compMainName;
	/**
	 * 统一社会信用代码
	 */
	private String creditCode;
	/**
	 * 实际经营地址
	 */
	private String busAddr;
	/**
	 * 立案日期
	 */
	private String recordDate;
	/**
	 * 案由
	 */
	private String ay;
	/**
	 * 报告单位名称
	 */
	private String rOrgname;
	/**
	 * 执法人员1
	 */
	private String supervisionPerson1;
	/**
	 * 执法人员2
	 */
	private String supervisionPerson2;
	/**
	 * 处罚程序
	 */
	private String punishimentprocedure;
	/**
	 * 案件来源
	 */
	private String disciplineSource;
	/**
	 * 结案日期
	 */
	private Date closedDate;
	/**
	 * 罚没款
	 */
	private String deside;
	/**
	 * 实际履行罚款金额
	 */
	private String actualPenalty;
	/**
	 * 执行方式
	 */
	private String closedStatus;
	/**
	 * 执行结果
	 */
	private String result;
	/**
	 * 处罚依据
	 */
	private String punishmentBasis;
	/**
	 * 修改时间
	 */
	private Date sourceUpdateTime;
	/**
	 * 创建时间
	 */
	private Date sourceCreateTime;
	/**
	 * 原主键
	 */
	private String sourceId;
	/**
	 * 创建时间-数据同步时间
	 */
	private Date createDate;
	/**
	 * 最后修改时间-数据最后更新时间
	 */
	private Date updateDate;


}

==> rho-common-facade-2.0.0-sources.jar: cn/smarthse/rho/modules/sys/entity/s/SupervisionExeLawInfo.java <==
package cn.smarthse.rho.modules.sys.entity.s;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;




//@ApiModel(value = "放射卫生执法处罚 对象", description = "医院：放射卫生执法处罚")
@TableName("supervision_exe_law_info")
@Data
public class SupervisionExeLawInfo implements Serializable{
	private static final long serialVersionUID = 1L;
	/**
	 * ID
	 */
	@TableId(value = "id", type = IdType.ASSIGN_ID)
	private Long id;
	/**
	 * 医院分院id
	 */
	private Long cid;
	/**
	 * 医院分院名称
	 */
	private String compName;
	/**
	 * 医院主院id
	 */
	private Long mainCid;
	/**
	 * 对应主院医院名称
	 */
	private String compMainName;
	/**
	 * 统一社会信用代码
	 */
	private String creditCode;
	/**
	 * 实际经营地址
	 */
	private String busAddr;
	/**
	 * 立案日期
	 */
	private String recordDate;
	/**
	 * 案由
	 */
	private String ay;
	/**
	 * 报告单位名称
	 */
	private String rOrgname;
	/**
	 * 执法人员1
	 */
	private String supervisionPerson1;
	/**
	 * 执法人员2
	 */
	private String supervisionPerson2;
	/**
	 * 处罚程序
	 */
	private String punishimentprocedure;
	/**
	 * 案件来源
	 */
	private String disciplineSource;
	/**
	 * 结案日期
	 */
	private Date closedDate;
	/**
	 * 罚没款
	 */
	private String deside;
	/**
	 * 实际履行罚款金额
	 */
	private String actualPenalty;
	/**
	 * 执行方式
	 */
	private String closedStatus;
	/**
	 * 执行结果
	 */
	private String result;
	/**
	 * 处罚依据
	 */
	private String punishmentBasis;
	/**
	 * 修改时间
	 */
	private Date sourceUpdateTime;
	/**
	 * 创建时间
	 */
	private Date sourceCreateTime;
	/**
	 * 原主键
	 */
	private String sourceId;
	/**
	 * 创建时间-数据同步时间
	 */
	private Date createDate;
	/**
	 * 最后修改时间-数据最后更新时间
	 */
	private Date updateDate;


}
